@@ -158,9 +158,15 @@ class LikeOp(_BinaryOp):
             self._field += '.' + field_ext
         if not isinstance(to_match, str):
             raise SQLDecodeError
-
-        to_match = re.escape(to_match).replace('%', '.*')
-        self._regex = f'^{to_match}$'
+        # Like expression special character
+        to_match = to_match.replace('\\%', '%')
+        # Like expression special character
+        to_match = to_match.replace('\\_', '_')
+        # Ensure all regex special characters are handled
+        to_match = re.escape(to_match)
+        # Remove percentage characters for like expression: %query% -> query
+        to_match = to_match[1:-1]
+        self._regex = to_match
 
     def to_mongo(self):
         return {self._field: {'$regex': self._regex}}
